Module beamlit.models.environment_metrics
=========================================

Classes
-------

`EnvironmentMetrics(inference_global: beamlit.types.Unset | list['Metric'] = <beamlit.types.Unset object>)`
:   Metrics for the environment
    
    Attributes:
        inference_global (Union[Unset, list['Metric']]): Array of metrics
    
    Method generated by attrs for class EnvironmentMetrics.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `inference_global`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :